use clap::Parser;
use log::trace;

use crate::commands::Cli;

/// pkgr's commands.
mod commands;
/// Logging implementations for pkgr.
mod logging;
/// Package and helpers.
mod package;
/// Process wrapper with logging wrapper.
mod process;
/// tmpfs wrapper.
mod tmpfs;
/// pkgr's optional config.
mod config;
/// custom types used by pkgr
mod types;
/// utils
mod util;
mod api;

thread_local! {
    static CONFIG: config::Config = config::Config::from_path("/etc/pkgr.toml")
                                        .unwrap_or(config::Config::default());
}

fn main() {
    logging::setup_logger()
        .expect("unable to set logger.");

    #[cfg(not(debug_assertions))]
    {
        if unsafe { libc::getuid() } != 0 {
            use log::error;
            error!("pkgr must be run as root.");
            std::process::exit(1);
        }
    }

    trace!("Parsing command line arguments...");
    let c = Cli::parse();
    trace!("Command line arguments: {:?}", c);

    trace!("Executing command...");
    c.command.execute();
    trace!("Command executed.");

    trace!("Exiting...");
}
