use log::trace;
use crate::package::Package;

pub struct PackageQueue {
    packages: Vec<Package>
}

impl PackageQueue {
    pub fn new() -> Self {
        PackageQueue {
            packages: vec![]
        }
    }

    pub fn add_package(&mut self, package: Package, build: bool) {
        let dependencies = package.dependencies();
        for dependency in dependencies {
            trace!("Checking package: {}", &dependency.identifier);
            if self.packages.contains(&dependency) {
               continue
            }
            trace!("Adding package: {}", &dependency.identifier);
            self.packages.push(dependency);
        }
        if !self.packages.contains(&package) {
            self.packages.push(package);
        }
    }

    pub fn install(&mut self, build: bool) {
        self.packages
            .iter_mut()
            .for_each(|pkg| {
                pkg.install(build);
            });
    }
}
